@@ -10,7 +10,7 @@ from pathlib import Path
 from xml.etree import ElementTree as ET
 
 import pytest
-from conftest import skip_if_pypy
+from conftest import skip_if_ci, skip_if_pypy
 from hypothesis import assume, example, given, settings
 from hypothesis import strategies as st
 from hypothesis.strategies import integers
@@ -254,6 +254,7 @@ def test_decode_pdf_date():
     VALS = [
         ('20160220040559', datetime(2016, 2, 20, 4, 5, 59)),
         ("20180101010101Z00'00'", datetime(2018, 1, 1, 1, 1, 1, tzinfo=timezone.utc)),
+        ("20180101010101Z00'00", datetime(2018, 1, 1, 1, 1, 1, tzinfo=timezone.utc)),
         ("20180101010101Z", datetime(2018, 1, 1, 1, 1, 1, tzinfo=timezone.utc)),
         ("20180101010101+0000", datetime(2018, 1, 1, 1, 1, 1, tzinfo=timezone.utc)),
         (
@@ -268,8 +269,8 @@ def test_decode_pdf_date():
 def test_date_docinfo_from_xmp():
     VALS = [
         ('2018-12-04T03:02:01', "D:20181204030201"),
-        ('2018-12-15T07:36:43Z', "D:20181215073643+00'00'"),
-        ('2018-12-04T03:02:01-01:00', "D:20181204030201-01'00'"),
+        ('2018-12-15T07:36:43Z', "D:20181215073643+00'00"),
+        ('2018-12-04T03:02:01-01:00', "D:20181204030201-01'00"),
     ]
     for xmp_val, docinfo_val in VALS:
         assert DateConverter.docinfo_from_xmp(xmp_val) == docinfo_val
@@ -554,7 +555,7 @@ def test_extension_level(trivial, outpdf):
         trivial.save(outpdf, force_version=('1.7', 'invalid extension level'))
 
 
-@settings(deadline=500.0)
+@settings(deadline=60000)
 @given(
     st.dictionaries(
         keys=st.sampled_from(
@@ -607,6 +608,7 @@ def test_random_docinfo(docinfo):
     )
 )
 @skip_if_pypy
+@skip_if_ci
 def test_random_valid_docinfo(docinfo):
     p = pikepdf.new()
     with p.open_metadata() as m:
@@ -616,7 +618,7 @@ def test_random_valid_docinfo(docinfo):
         ET.fromstring(str(m))  # ensure we can parse it
 
 
-@pytest.mark.parametrize('author', ['', 'King, S.'])
+@pytest.mark.parametrize('author', ['Queen, C.', 'King, S.'])
 def test_issue_162(trivial, author):
     trivial.Root.Metadata = Stream(
         trivial,
@@ -663,15 +665,17 @@ def test_dont_create_empty_docinfo(trivial, outpdf, fix_metadata):
 
 
 def test_issue_100(trivial):
-    with trivial.open_metadata() as m, pytest.warns(
-        UserWarning, match="no XMP equivalent"
+    with (
+        trivial.open_metadata() as m,
+        pytest.warns(UserWarning, match="no XMP equivalent"),
     ):
         m.load_from_docinfo({'/AAPL:Example': pikepdf.Array([42])})
 
 
 def test_issue_135_title_rdf_bag(trivial):
-    with trivial.open_metadata(update_docinfo=True) as xmp, pytest.warns(
-        UserWarning, match="Merging elements"
+    with (
+        trivial.open_metadata(update_docinfo=True) as xmp,
+        pytest.warns(UserWarning, match="Merging elements"),
     ):
         xmp['dc:title'] = {'Title 1', 'Title 2'}
     with trivial.open_metadata(update_docinfo=False) as xmp:
@@ -679,17 +683,14 @@ def test_issue_135_title_rdf_bag(trivial):
 
 
 def test_xmp_metadatadate_timezone(sandwich, outpdf):
-    with sandwich.open_metadata():
+    with sandwich.open_metadata(set_pikepdf_as_editor=True):
         pass
     sandwich.save(outpdf)
-
-    machine_tz = datetime.utcnow().astimezone().tzinfo
-
     with Pdf.open(outpdf) as pdf:
         with pdf.open_metadata() as m:
             dt = datetime.fromisoformat(m['xmp:MetadataDate'])
             assert dt.tzinfo is not None
-            assert dt.tzinfo == machine_tz
+            assert dt.tzinfo == timezone.utc
 
 
 def test_modify_not_opened(graph):
@@ -735,4 +736,98 @@ def test_xxe(trivial, outdir):
 
 
 def test_qname_no_namespace():
-    assert PdfMetadata._qname('abc') == '{adobe:ns:meta/}abc'
+    assert PdfMetadata._qname('abc') == 'abc'
+
+
+def test_register_xmlns():
+    PdfMetadata.register_xml_namespace('http://github.com/pikepdf/pikepdf/', 'pikepdf')
+    assert (
+        PdfMetadata._qname('pikepdf:foo') == '{http://github.com/pikepdf/pikepdf/}foo'
+    )
+
+
+def test_undocumented_pdfx_identifier(trivial):
+    trivial.Root.Metadata = Stream(
+        trivial,
+        """\
+<x:xmpmeta xmlns:x="adobe:ns:meta/" x:xmptk="Adobe XMP Core 4.0-c316 44.253921, Sun Oct 01 2006 17:14:39">
+   <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <rdf:Description xmlns:dc="http://purl.org/dc/elements/1.1/" rdf:about="">
+         <dc:format>application/pdf</dc:format>
+         <dc:title>
+            <rdf:Alt>
+               <rdf:li xml:lang="x-default">A</rdf:li>
+            </rdf:Alt>
+         </dc:title>
+         <dc:creator>
+            <rdf:Seq>
+               <rdf:li>B</rdf:li>
+               <rdf:li>C</rdf:li>
+            </rdf:Seq>
+         </dc:creator>
+         <dc:description>
+            <rdf:Alt>
+               <rdf:li xml:lang="x-default">D</rdf:li>
+            </rdf:Alt>
+         </dc:description>
+         <dc:publisher>
+            <rdf:Bag>
+               <rdf:li>E</rdf:li>
+            </rdf:Bag>
+         </dc:publisher>
+      </rdf:Description>
+      <rdf:Description xmlns:prism="http://prismstandard.org/namespaces/basic/3.0/" rdf:about="">
+         <prism:aggregationType>journal</prism:aggregationType>
+         <prism:publicationName>Journal</prism:publicationName>
+         <prism:copyright>© 2023</prism:copyright>
+         <prism:issn>1234-5678</prism:issn>
+         <prism:volume>1</prism:volume>
+         <prism:number>1</prism:number>
+         <prism:coverDisplayDate>March-April 2023</prism:coverDisplayDate>
+         <prism:pageRange>1-2</prism:pageRange>
+         <prism:startingPage>1</prism:startingPage>
+         <prism:endingPage>2</prism:endingPage>
+      </rdf:Description>
+      <rdf:Description xmlns:pdfx="http://ns.adobe.com/pdfx/1.3/" rdf:about="">
+         <TGji2z9aLyPf_nweGmtj-nLNNnt2Nlwj7yteGngiQzd2Sy937zt-Jo9eQmdmKn9yJmMmTma/>
+         <pdfx:robots>noindex</pdfx:robots>
+      </rdf:Description>
+      <rdf:Description xmlns:xap="http://ns.adobe.com/xap/1.0/" rdf:about="">
+         <xap:CreatorTool>NA</xap:CreatorTool>
+         <xap:CreateDate>2023-03-07T23:47:54+05:30</xap:CreateDate>
+         <xap:ModifyDate>2023-03-07T23:48:24+05:30</xap:ModifyDate>
+         <xap:MetadataDate>2023-03-07T23:48:24+05:30</xap:MetadataDate>
+      </rdf:Description>
+      <rdf:Description xmlns:xapRights="http://ns.adobe.com/xap/1.0/rights/" rdf:about="">
+         <xapRights:Marked>True</xapRights:Marked>
+      </rdf:Description>
+      <rdf:Description xmlns:pdf="http://ns.adobe.com/pdf/1.3/" rdf:about="">
+         <pdf:Producer>Acrobat Distiller 8.1.0 (Windows)</pdf:Producer>
+      </rdf:Description>
+      <rdf:Description xmlns:xapMM="http://ns.adobe.com/xap/1.0/mm/" rdf:about="">
+         <xapMM:DocumentID>uuid:81b6d753-a810-4613-b207-111111111111</xapMM:DocumentID>
+         <xapMM:InstanceID>uuid:0d50ecbf-b7d1-4b76-b4a7-222222222222</xapMM:InstanceID>
+      </rdf:Description>
+   </rdf:RDF>
+</x:xmpmeta>
+""".encode(),
+    )
+    with trivial.open_metadata() as m:
+        list(m.items())
+
+
+@pytest.mark.parametrize('assign,expect', [([], []), ([''], [None]), ([None], [None])])
+def test_empty_list(graph, outpdf, assign, expect):
+    with graph.open_metadata() as m:
+        m['dc:creator'] = assign
+        assert (
+            m['dc:creator'] == expect
+        ), f"Before saving, expected {expect}, got {m['dc:creator']}"
+
+    graph.save(outpdf)
+
+    with pikepdf.open(outpdf) as pdf:
+        with pdf.open_metadata() as m:
+            assert (
+                m['dc:creator'] == expect
+            ), f"After saving, expected {expect}, got {m['dc:creator']}"
